function interactive_phase_plot(f, range, simutime)
% Interactive phase portrait plot for a SECOND order ODE
%% 
% f:  the system function that will besolve using ode45 (integration)
% range: is the limits for the axes ([xmin xmax; ymin ymax]), since we have
% planar system (x stands for x1, y stands for x2)
% simtime: is the simulation time
% Inspiration from
%     http://matlab.cheme.cmu.edu/2011/08/09/phase-portraits-of-a-system-of-odes/

%% scale is used to adjust the dimension of the arrows
%     this corresponds to the AutoScale property of the quiver function
scale = 0.5;
%% reso: resolution is used to define how many arrows will be drawn
%     (horizontal resolution (the x-axis) x vertical resolution (the y-axis))
reso = [20 20];
set(0,'defaulttextInterpreter','latex') %latex axis labels

%% Vector field
    x1 = linspace(range(1, 1), range(1, 2), reso(1));
    x2 = linspace(range(2, 1), range(2, 2), reso(2));

    [X1, X2] = meshgrid(x1, x2);
    u = zeros(size(X1));
    v = zeros(size(X2));

    t = 0; 
    for i = 1:numel(X1)
        X_DOT = f(t,[X1(i); X2(i)]);
        Vmod = sqrt(X_DOT(1)^2 + X_DOT(2)^2);
        u(i) = X_DOT(1)/Vmod; %normalized
        v(i) = X_DOT(2)/Vmod;
    end

    % Drawing
    h = figure;
    hq = quiver(X1, X2, u, v, 'r'); 
    hq.AutoScaleFactor = scale;
    hold on;
    xlabel('$x1$', 'interpreter', 'latex')
    ylabel('$x2$', 'interpreter', 'latex')
    axis tight equal;
    xlim(range(1,:));
    ylim(range(2,:));

%%  For current initial values
    while ishandle(h)
        try
            x0 = ginput(1); % waits for the user click on the figure
        catch
            break;
        end
        
        [~, x] = ode45(f, 0:0.01:simutime, x0); % ode45 at 1 khz
        plot(x(:,1), x(:,2), 'b', 'LineWidth', 2);
        plot(x(1,1), x(1,2), 'om')
    end
end

